@@ -2,7 +2,6 @@
 Viewset for Tags.
 """
 from edx_api_doc_tools import query_parameter, schema_for
-from eox_audit_model.decorators import audit_method
 from rest_framework import status, viewsets
 from rest_framework.authentication import SessionAuthentication
 
@@ -14,6 +13,13 @@ from eox_tagging.edxapp_accessors import get_site
 from eox_tagging.edxapp_wrappers.bearer_authentication import BearerAuthentication
 from eox_tagging.models import Tag
 
+try:
+    from eox_audit_model.decorators import audit_method
+except ImportError:
+    def audit_method(*args, **kwargs):  # pylint: disable=unused-argument
+        """Identity decorator"""
+        return lambda x: x
+
 
 @schema_for(
     "create",
@@ -228,7 +234,7 @@ class TagViewSet(viewsets.ModelViewSet):
 
         @audit_method(action="eox_tagging-api-v1-viewset:tagviewset-create")
         def audited_create(body):  # pylint: disable=unused-argument
-            return super(TagViewSet, self).create(request, *args, **kwargs)
+            return super(TagViewSet, self).create(request, *args, **kwargs)  # pylint: disable=super-with-arguments
 
         return audited_create(body=request.data)
 
@@ -241,7 +247,7 @@ class TagViewSet(viewsets.ModelViewSet):
 
         @audit_method(action="eox_tagging-api-v1-viewset:tagviewset-destroy")
         def audited_destroy(path):  # pylint: disable=unused-argument
-            return super(TagViewSet, self).destroy(request, *args, **kwargs)
+            return super(TagViewSet, self).destroy(request, *args, **kwargs)  # pylint: disable=super-with-arguments
 
         return audited_destroy(path=request.path)
 
